@@ -13,6 +13,7 @@ from typing import ForwardRef
 from devtools import PrettyFormat, pprint, pformat, debug
 import json
 import yaml
+from datasize import DataSize
 
 from aws_pcluster_helpers import (
     PClusterConfig,
@@ -88,15 +89,13 @@ class DaskGatewaySlurmConfig(sinfo.SInfoTable):
         profiles = {}
         for sinfo_row in self.rows:
             label = f"P: {sinfo_row.queue}, I: {sinfo_row.ec2_instance_type}, CPU: {sinfo_row.vcpu}, Mem: {sinfo_row.mem}"
+            memory = sinfo_row.mem / sinfo_row.vcpu
+            memory = in(DataSize(f"{sinfo_row.mem}Gi"))
             profiles[label] = {
                 "worker_cores": sinfo_row.vcpu,
                 "scheduler_cores": sinfo_row.vcpu,
-                "worker_memory": f"{sinfo_row.mem} GiB",
-                "scheduler_memory": f"{sinfo_row.mem} GiB",
-                # sinfo_row.mem is the memory in GiB
-                # We want it from GiB to the format dask expects
-                # "worker_memory": int(sinfo_row.mem * 2 ** 30),
-                # "scheduler_memory": int(sinfo_row.mem * 2 ** 30),
+                "worker_memory": memory,
+                "scheduler_memory": memory,
                 "constraint": sinfo_row.constraint,
                 "partition": sinfo_row.queue,
             }
